
! Copyright (C) 2013 J. K. Dewhurst, S. Sharma and E. K. U. Gross.
! This file is distributed under the terms of the GNU General Public License.
! See the file COPYING for license details.

subroutine writestress
use modmain
use modmpi
use modtest
implicit none
! local variables
integer i,j,k
! initialise universal variables
call init0
! start from the atomic densities
trdstate=.false.
! generate the stress tensors
call genstress
! write the stress tensors to file
if (mp_mpi) then
  open(50,file='STRESS.OUT',form='FORMATTED',action='WRITE')
  write(50,*)
  write(50,'("Lattice vector matrix, A, changed by")')
  write(50,*)
  write(50,'("     A → A + eₖ dt,")')
  write(50,*)
  write(50,'("where dt is an infinitesimal scalar and eₖ is a strain tensor")')
  write(50,*)
  write(50,'("Stress is given by the derivative of the total energy dE/dt")')
  do k=1,nstrain
    write(50,*)
    write(50,'("Strain tensor k : ",I1)') k
    do j=1,3
      write(50,'(3G18.10)') (strain(i,j,k),i=1,3)
    end do
    write(50,'("Stress : ",G18.10)') stress(k)
  end do
  close(50)
  write(*,*)
  write(*,'("Info(writestress):")')
  write(*,'(" Stress tensor components written to STRESS.OUT")')
end if
! write test file if required
call writetest(440,'Stress tensor components',nv=nstrain,tol=1.d-2,rva=stress)
end subroutine

